==> aliyun-java-sdk-ecs-4.24.20-sources.jar: com/aliyuncs/ecs/model/v20140526/CreateLaunchTemplateVersionResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.ecs.transform.v20140526.CreateLaunchTemplateVersionResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class CreateLaunchTemplateVersionResponse extends AcsResponse {

	private Long launchTemplateVersionNumber;

	private String requestId;

	public Long getLaunchTemplateVersionNumber() {
		return this.launchTemplateVersionNumber;
	}

	public void setLaunchTemplateVersionNumber(Long launchTemplateVersionNumber) {
		this.launchTemplateVersionNumber = launchTemplateVersionNumber;
	}

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	@Override
	public CreateLaunchTemplateVersionResponse getInstance(UnmarshallerContext context) {
		return	CreateLaunchTemplateVersionResponseUnmarshaller.unmarshall(this, context);
	}
}

==> aliyun-java-sdk-ecs-4.24.63-sources.jar: com/aliyuncs/ecs/model/v20140526/CreateLaunchTemplateVersionResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.ecs.transform.v20140526.CreateLaunchTemplateVersionResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class CreateLaunchTemplateVersionResponse extends AcsResponse {

	private Long launchTemplateVersionNumber;

	private String requestId;

	private String launchTemplateId;

	public Long getLaunchTemplateVersionNumber() {
		return this.launchTemplateVersionNumber;
	}

	public void setLaunchTemplateVersionNumber(Long launchTemplateVersionNumber) {
		this.launchTemplateVersionNumber = launchTemplateVersionNumber;
	}

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public String getLaunchTemplateId() {
		return this.launchTemplateId;
	}

	public void setLaunchTemplateId(String launchTemplateId) {
		this.launchTemplateId = launchTemplateId;
	}

	@Override
	public CreateLaunchTemplateVersionResponse getInstance(UnmarshallerContext context) {
		return	CreateLaunchTemplateVersionResponseUnmarshaller.unmarshall(this, context);
	}
}
